@@ -213,6 +213,7 @@ pub unsafe trait EnumSetType: Copy + Eq + EnumSetTypePrivate { }
 /// instead serialized as a list of enum variants. This requires your enum type implement
 /// [`Serialize`] and [`Deserialize`]. Note that this is a breaking change
 #[derive(Copy, Clone, PartialEq, Eq)]
+#[repr(transparent)]
 pub struct EnumSet<T: EnumSetType> {
     #[doc(hidden)]
     /// This is public due to the [`enum_set!`] macro.
@@ -561,6 +562,7 @@ impl <T: EnumSetType + Debug> Debug for EnumSet<T> {
     }
 }
 
+#[allow(clippy::derive_hash_xor_eq)] // This impl exists to change trait bounds only.
 impl <T: EnumSetType> Hash for EnumSet<T> {
     fn hash<H: Hasher>(&self, state: &mut H) {
         self.__priv_repr.hash(state)
